.. currentmodule:: sardana.pool

.. _sardana-1d-overview:

=======================
1D channel overview
=======================

.. todo:: document 1D experiment channel overview

.. seealso:: 
    
    :ref:`sardana-1d-api`
        the 1D experiment channel :term:`API` 
    
    :class:`~sardana.tango.pool.OneDExpChannel.OneDExpChannel`
        the 1D experiment channel tango device :term:`API`
